@@ -64,7 +64,7 @@ class Database:
                 setattr(self, key, method)
             elif db_type is DatabaseType.SQL:
                 if key is 'Id':
-                   method = partial(db.Column, db.String, primary_key=True)
+                   method = partial(db.Column, primary_key=True)
                 elif key is 'Link':
                    method = partial(Database.handle_link, db)
                 else:
@@ -95,7 +95,7 @@ class FlaskData(Database):
             self.initialize(app)
 
     def initialize(self, app: Flask):
-        os.environ[f'{app.app.name.upper()}DIR'] = self.config_directory
+        os.environ[f'{app.name.upper()}DIR'] = self.config_directory
         config = confuse.Configuration(app.name, __name__)
         self.url = config['database']['url'].get(str)
         self.pool_size = config['database']['pool_size'].get(int)
